from calculator import Calculator

calc = Calculator()
calc.reset()
calc.add(2)  # Expected output: 2
calc.multiply(3)  # Expected output: 6
calc.root(2)  # Expected output: 2.449
calc.reset()
calc.subtract(5)  # Expected output: -5
calc.divide(2)  # Expected output: -2.5



import unittest
from calculator import Calculator

class TestCalculator(unittest.TestCase):
    def test_add(self): # test the addition

        calc = Calculator()
        calc.add(2)
        self.assertEqual(calc.memory, 2)
        
    def test_subtract(self): # test the subtraction
        calc = Calculator()
        calc.subtract(2)
        self.assertEqual(calc.memory, -2)
        
    def test_multiply(self): # test the multiplication
        calc = Calculator()
        calc.multiply(2)
        self.assertEqual(calc.memory, 0)
        
    def test_divide(self): # test the divide
        calc = Calculator()
        calc.divide(2)
        self.assertEqual(calc.memory, 0)
        with self.assertRaises(ValueError): # with the case of the denominator being 0
            calc.divide(0)
        
    def test_root(self): # test the root
        calc = Calculator()
        calc.root(2)
        self.assertEqual(calc.memory, 0)
        
    def test_reset(self): # test the reset
        calc = Calculator()
        calc.add(2)
        calc.reset()
        self.assertEqual(calc.memory, 0)


if __name__ == '__main__':
    unittest.main()


class Calculator:
    def __init__(self):
        self.memory = 0 # an initial value is 0
    
    def add(self, num): # for the addition
        self.memory += num
        return self.memory #show the current value in memory
    
    def subtract(self, num): # for the subtraction
        self.memory -= num
        return self.memory
    
    def multiply(self, num): # for the multiplication 
        self.memory *= num
        return self.memory
    
    def divide(self, num): # for the divide
        if num == 0:
            raise ValueError("Cannot divide by zero")
        self.memory /= num
        return self.memory
    
    def root(self, n): # for the root
        self.memory **= (1/n)
        return self.memory
    
    def reset(self): # to reset the memory back to 0
        self.memory = 0
        return self.memory
